
Changelog
=========

1.0.5.4 (2015-07-04)
-----------------------------------------
* "fix bugs for GUI related problems on *nix and Windows"
* "fix style errors and encoding problems"


1.0.5.3 (2015-07-03)
-----------------------------------------
* "fix bugs suggested by landscape.io"


1.0.5.2 (2015-07-02)
-----------------------------------------
This version is more relate with Windows support:

* support for .doc on windows with antiword 
* rewrite method to walk on directory based on scandir and modifacation of it. 
* fix a bug on windows when it tried to perform some search on depth
* fix a bug with workers/run_path.py that caused two calls for these method
* fix bugs with the fucking encoding and the arguments to subprocess  
* fix bug of logging and colors on terminal of windows.

1.0.5.1 (2015-06-30)
-----------------------------------------

* fix some bugs with gui

1.0.5 (2015-03-01)
-----------------------------------------

* First release on PyPI.
